# Czajkowski, M., Budziski, W., Campbell, D., Giergiczny, M., & Hanley, N. (2015). 
# Spatial heterogeneity of willingness to pay for forest management

# Kriging of WTP-scores

# Reading packages
library(spdep)
library(maptools)
library(sp)
library(RColorBrewer)
library(classInt)
library(kriging)
library(mgcv)
library(GISTools)

# Reading datasets (set your own paths)

setwd("C:\\Users\\wbudzinski\\Documents\\praca\\Spatial\\20160608\\Codes")
pl<-readShapePoly("dane10kmnowe.shp")
crds2<-coordinates(pl)

# Reading data file with WTP-scores
dane<-read.csv("Spatial_1201x.csv", sep=";",dec = ".",  header=TRUE) 
# Reading jittered coordinates 
crds<-read.csv("Crds0910.csv", sep=",",dec = ".",  header=TRUE) 
plot(pl)
points(crds, pch=21, bg="red", cex=1.1) 




################################## SQ #################################################
pred<-data.frame(Crds1 = crds2[,1],Crds2= crds2[,2])
data<-data.frame(SQ = dane$SQ, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- SQ~s(Crds1,Crds2)
hist(data$SQ,30)
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,40)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")  # wybr kolorw YlGnBu
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)


legend(x =-112000 ,y=690000, legend=leg,title = expression(WTP~scores~'for'~italic(SQ))    , fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)
map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

xy = locator(1) # click on whatever on the map

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### NAT 1 ################################################
data<-data.frame(x = dane$NAT1, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- x~s(Crds1,Crds2)
hist(data$x,30)
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,40)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")   # wybr kolorw
klasy<-classIntervals(predfit, style="quantile", n = 10)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)

map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-112000 ,y=690000, legend=leg,title = expression(WTP~scores~'for'~italic(NAT)[1]), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### NAT 2 ################################################
data<-data.frame(x = dane$NAT2, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- x~s(Crds1,Crds2)
hist(data$x,30)
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,40)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd") 
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)

map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-112000 ,y=690000, legend=leg,title = expression(WTP~scores~'for'~italic(NAT)[2]), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### INF1 ################################################
data<-data.frame(x = dane$INF1, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- x~s(Crds1,Crds2)
hist(data$x,30)
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,40)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")   # wybr kolorw
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)


map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-112000 ,y=690000, legend=leg,title = expression(WTP~scores~'for'~italic(INF)[1]), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### INF2 ################################################
data<-data.frame(x = dane$INF2, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- x~s(Crds1,Crds2)
hist(data$x,30)
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,40)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")   # wybr kolorw
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)
map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-112000 ,y=690000, legend=leg,title = expression(WTP~scores~'for'~italic(INF)[2]), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### TRA1 ################################################
data<-data.frame(x = dane$TRA1, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- x~s(Crds1,Crds2)
hist(data$x,30)
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,40)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")   # wybr kolorw
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)

map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-112000 ,y=690000, legend=leg,title = expression(WTP~scores~'for'~italic(TRA)[1]), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### TRA2 ################################################
data<-data.frame(x = dane$TRA2, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- x~s(Crds1,Crds2)
hist(data$x,30)
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,40)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")   # wybr kolorw
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)

map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-112000 ,y=690000, legend=leg,title = expression(WTP~scores~'for'~italic(TRA)[2]), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### FEE ################################################
data<-data.frame(x = dane$FEE, Crds1 = crds[,1], Crds2 = crds[,2])
formula<- x~s(Crds1,Crds2)
hist(data$x,30)
gam1<- gam(formula, data = data, family = gaussian(link = log))
summary(gam1)
hist(gam1$residuals,60)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")   # wybr kolorw
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)

map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-110000 ,y=700000, legend=leg,title = expression(italic(COST)~parameter~scores), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)

xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)

################################### FEE - norm ################################################
gam1<- gam(formula, data = data, family = gaussian(link = identity))
summary(gam1)
hist(gam1$residuals,60)
p.gam <- predict(gam1, newdata=pred, type="response", se.fit=TRUE)

predfit<-p.gam$fit
summary(predfit)

kolory<-brewer.pal(9, "YlOrRd")   # wybr kolorw
klasy<-classIntervals(predfit, style="quantile", n = 9)
tabela.kolorw<-findColours(klasy, kolory) 
plot(pl, col=tabela.kolorw)

leg1<-paste("[" , as.character(round(klasy$brks[1],2)) , ",",  as.character(round(klasy$brks[2],2)),")", sep="")
leg2<-paste("[" , as.character(round(klasy$brks[2],2)) , ",",  as.character(round(klasy$brks[3],2)),")", sep="")
leg3<-paste("[" , as.character(round(klasy$brks[3],2)) , ",",  as.character(round(klasy$brks[4],2)),")", sep="")
leg4<-paste("[" , as.character(round(klasy$brks[4],2)) , ",",  as.character(round(klasy$brks[5],2)),")", sep="")
leg5<-paste("[" , as.character(round(klasy$brks[5],2)) , ",",  as.character(round(klasy$brks[6],2)),")", sep="")
leg6<-paste("[" , as.character(round(klasy$brks[6],2)) , ",",  as.character(round(klasy$brks[7],2)),")", sep="")
leg7<-paste("[" , as.character(round(klasy$brks[7],2)) , ",",  as.character(round(klasy$brks[8],2)),")", sep="")
leg8<-paste("[" , as.character(round(klasy$brks[8],2)) , ",",  as.character(round(klasy$brks[9],2)),")", sep="")
leg9<-paste("[" , as.character(round(klasy$brks[9],2)) , ",",  as.character(round(klasy$brks[10],2)),")", sep="")
leg<-c(leg1, leg2, leg3, leg4, leg5, leg6, leg7, leg8, leg9)

map.scale(20000,250000,len = 100000, units = "km",ndivs = 2,subdiv = 50)

legend(x =-112000 ,y=690000, legend=leg,title = expression(italic(COST)~parameter~scores), fill=attr(tabela.kolorw, "palette"), 
       cex=0.95, bty="n", y.intersp = 0.9)

x_russia<-c(530000, 530000, 540000, 540000, 550000, 550000, 560000, 560000, 570000,570000)
y_russia<-c(740000, 750000, 750000, 760000, 760000, 770000, 770000, 780000, 780000,790000)
lines(x = x_russia, y = y_russia)
x_russia2<-c(740000, 740000, 740000, 740000, 750000,750000)
y_russia2<-c(740000, 750000, 760000, 770000, 770000,780000)
lines(x = x_russia2, y = y_russia2)
x_lit<-c(810000, 820000, 830000, 840000, 850000)
y_lit<-c(660000, 660000, 660000, 660000, 660000 )
lines(x = x_lit, y = y_lit)
x_biel<-c(820000, 830000, 840000, 840000, 840000, 850000, 860000 )
y_biel<-c(440000, 440000, 440000, 450000, 460000, 460000, 460000)
lines(x = x_biel, y = y_biel)
x_ukr<-c(760000, 760000, 750000, 750000, 750000, 740000, 740000, 750000, 750000, 740000)
y_ukr<-c(130000, 120000, 120000, 110000, 100000, 100000,  90000,  90000,  80000,  80000)
lines(x = x_ukr, y = y_ukr)
x_slov<-c(490000, 480000, 470000, 470000, 460000, 460000, 450000, 450000)
y_slov<-c(160000, 160000, 160000, 150000, 150000, 140000, 140000, 130000)
lines(x = x_slov, y = y_slov)
x_czech<-c(200000, 200000, 190000, 180000, 180000, 180000, 170000, 160000)
y_czech<-c(340000, 330000, 330000, 330000, 340000, 350000, 350000, 350000)
lines(x = x_czech, y = y_czech)
x_ger<-c(180000, 170000, 160000, 160000, 150000, 150000, 140000, 140000)
y_ger<-c(690000, 690000, 690000, 700000, 700000, 710000, 710000, 720000)
lines(x = x_ger, y = y_ger)

xy$x<-278720.1
xy$y<-777574.7
text(xy,labels="The Baltic Sea",cex=0.9,pos=1,offset = 0.3)
xy$x<-645197.7
xy$y<-777574.7
text(xy,labels="Russia",cex=0.9,pos=1,offset = 0.3)
xy$x<-815881.4
xy$y<-777574.7
text(xy,labels="Lithuania",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-578060.2
text(xy,labels="Belarus",cex=0.9,pos=1,offset = 0.3)
xy$x<-890756.3
xy$y<-225766.4
text(xy,labels="Ukraine",cex=0.9,pos=1,offset = 0.3)
xy$x<-622411
xy$y<-138332.6
text(xy,labels="Slovakia",cex=0.9,pos=1,offset = 0.3)
xy$x<-247330.4
xy$y<-232509
text(xy,labels="The Czech Republic",cex=0.9,pos=1,offset = 0.3)
xy$x<-150124.5
xy$y<-540854.4
text(xy,labels="Germany",cex=0.9,pos=1,offset = 0.3)


xy$x<-658843.8
xy$y<-496760.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Warsaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-576751.1
xy$y<-243343.5
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Cracow",cex=1.6,pos=3,offset = 0.3)

xy$x<-482166
xy$y<-725192.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Gdansk",cex=1.6,pos=1,offset = 0.3)

xy$x<-373303.8
xy$y<-348636.4
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Wroclaw",cex=1.6,pos=1,offset = 0.3)

xy$x<-364380.7
xy$y<-511037.2
points(xy, pch=21, bg="black", cex=1.4) 
text(xy,labels="Poznan",cex=1.6,pos=4,offset = 1)