# Czajkowski, M., Budziski, W., Campbell, D., Giergiczny, M., & Hanley, N. (2015). 
# Spatial heterogeneity of willingness to pay for forest management

# Linear regressions, spatial lag models & LM tests

# Reading packages

library(spdep)
library(maptools)
library(sp)
library(RColorBrewer)
library(classInt)

# Reading datasets (set your own paths)

setwd("C:\\Users\\wbudzinski\\Documents\\praca\\Spatial\\20160608\\Codes")
pl<-readShapePoly("dane10kmnowe.shp")
dane<-read.csv("Spatial_1201x.csv", sep=";",dec = ".",  header=TRUE) 
crds<-read.csv("Crds0910.csv", sep=",",dec = ".",  header=TRUE) # jittered coordinates


# Calculating spatial weights matrix
crdsmat <-data.matrix(crds) #converting into matrix class
kw10km<-knearneigh(crdsmat, k=1000) 
kw10kmnb<-knn2nb(kw10km) 
dist<-nbdists(kw10kmnb, crdsmat)
dist2<-lapply(dist, function(x) 1/(x^2))  
kw10kmdist2<-nb2listw(kw10kmnb, glist=dist2) 

# Scaling variables

dane$logP16 <-log(dane$P16)
dane$logP18 <-log(dane$P18+1)
dane$PowLasu<-dane$PowLasu/100
dane$Wiek4<-dane$Wiek4/100
dane$Lgat3<-dane$Lgat3/100
dane$Igla<-dane$Igla/100
dane$Lisc<-dane$Lisc/100
dane$Miesz<-dane$Miesz/100
dane$Euclavg<-dane$Euclavg/1000
dane$EduHigh <- as.numeric(dane$Edu >9)
dane$Zabud<-dane$Zabud/100


############################# Estimation ################################

# NAT models 

OLS_dummy<-lm(NAT1~ 1, data=dane) # Dummy regression
logLik(OLS_dummy)


rownanie1 <- NAT1 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age + M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
summary(GIS2error)

OLS<-lm(rownanie1, data=dane) 
summary(OLS)

wynik<-lm.LMtests(OLS,kw10kmdist2, test = "all" )
print(wynik)



rownanie1 <- NAT2 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age + M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
summary(GIS2error)


OLS_dummy<-lm(NAT2~ 1, data=dane) 
logLik(OLS_dummy)

OLS<-lm(rownanie1, data=dane) 
summary(OLS)

wynik<-lm.LMtests(OLS,kw10kmdist2, test = "all" )
print(wynik)

# TRA models


rownanie1 <- TRA1 ~  Lisc+ Miesz+ Wiek4 +Euclavg+Age+EduHigh + M21 +logP16 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
summary(GIS2error)


OLS_dummy<-lm(TRA1~ 1, data=dane) 
logLik(OLS_dummy)

OLS<-lm(rownanie1, data=dane) 
summary(OLS)

wynik<-lm.LMtests(OLS,kw10kmdist2, test = "all" )
print(wynik)



rownanie1 <- TRA2 ~  Lisc+ Miesz+ Wiek4 +Euclavg+Age+EduHigh + M21 + logP16 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
summary(GIS2error)


OLS_dummy<-lm(TRA2~ 1, data=dane) 
logLik(OLS_dummy)


OLS<-lm(rownanie1, data=dane) 
summary(OLS)

wynik<-lm.LMtests(OLS,kw10kmdist2, test = "all" )
print(wynik)


# INF models



rownanie1 <- INF1 ~  Igla +Lisc + Miesz +Wiek4 +Euclavg+Age+ EduHigh +M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
summary(GIS2error)


OLS_dummy<-lm(INF1~ 1, data=dane) 
logLik(OLS_dummy)

OLS<-lm(rownanie1, data=dane) 
summary(OLS)

wynik<-lm.LMtests(OLS,kw10kmdist2, test = "all" )
print(wynik)


rownanie1 <- INF2 ~  Igla +Lisc + Miesz +Wiek4 +Euclavg+Age+ EduHigh +M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25) 
summary(GIS2error)


OLS_dummy<-lm(INF2~ 1, data=dane) 
logLik(OLS_dummy)

OLS<-lm(rownanie1, data=dane) 
summary(OLS)

wynik<-lm.LMtests(OLS,kw10kmdist2, test = "all" )
print(wynik)

##################################### Durbin model #################################################

rownanie1 <- NAT1 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age +EduHigh+ M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25, type = "mixed") 
summary(GIS2error)


rownanie1 <- NAT2 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age +EduHigh+ M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25, type = "mixed") 
summary(GIS2error)

rownanie1 <- TRA1 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age +EduHigh+ M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25, type = "mixed") 
summary(GIS2error)

rownanie1 <- TRA2 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age +EduHigh+ M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25, type = "mixed") 
summary(GIS2error)

rownanie1 <- INF1 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age +EduHigh+ M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25, type = "mixed") 
summary(GIS2error)

rownanie1 <- INF2 ~  Igla + Lisc+ Miesz+ Wiek4 +Euclavg+Age +EduHigh+ M21 +logP16 + logP18 
GIS2error <- lagsarlm(rownanie1, data=dane, kw10kmdist2, tol.solve=3e-25, type = "mixed") 
summary(GIS2error)

## Moran stats for WTP_score

wynik01<-moran.test(dane$NAT1, kw10kmdist2)
print(wynik01)

wynik01<-moran.test(dane$NAT2, kw10kmdist2)
print(wynik01)

wynik01<-moran.test(dane$TRA1, kw10kmdist2)
print(wynik01)
wynik01<-moran.test(dane$TRA2, kw10kmdist2)
print(wynik01)
wynik01<-moran.test(dane$INF1, kw10kmdist2)
print(wynik01)
wynik01<-moran.test(dane$INF2, kw10kmdist2)
print(wynik01)

